"""This module fixes some broken code from the generator.

"""
from schul_cloud_resources_api_v1.models.resource_response_links import ResourceResponseLinks

#
# Fix the _self attribute to be self
#

ResourceResponseLinks.self = ResourceResponseLinks.__dict__["_self"]


# coding: utf-8

"""
    Schul-Cloud Content API

    This is the specification for the content of Schul-Cloud. You can find more information in the [repository](https://github.com/schul-cloud/resources-api-v1). 

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

# import models into model package
from .error_element import ErrorElement
from .error_response import ErrorResponse
from .jsonapi import Jsonapi
from .jsonapi_meta import JsonapiMeta
from .resource import Resource
from .resource_ids_response import ResourceIdsResponse
from .resource_ids_response_data import ResourceIdsResponseData
from .resource_ids_response_links import ResourceIdsResponseLinks
from .resource_post import ResourcePost
from .resource_post_data import ResourcePostData
from .resource_response import ResourceResponse
from .resource_response_data import ResourceResponseData
from .resource_response_links import ResourceResponseLinks
from .resource_type import ResourceType



# coding: utf-8

"""
    Schul-Cloud Content API

"""


from __future__ import absolute_import

import os
import sys
import unittest

import schul_cloud_resources_api_v1
from schul_cloud_resources_api_v1.schema import (
    validate_resource, is_valid_resource, get_valid_examples,
    get_invalid_examples, ValidationFailed, get_schemas
)


class TestResourceSchema(unittest.TestCase):
    """ Schema unit test stubs """

    def test_there_are_valid_examples(self):
        self.assertTrue(get_valid_examples())

    def test_there_are_invalid_examples(self):
        self.assertTrue(get_invalid_examples())

    def test_valid_and_invalid_examples_are_not_the_same(self):
        for v in get_valid_examples():
            for i in get_invalid_examples():
                self.assertNotEqual(v, i, "A valid example can not be invalid.")

    def test_all_valid_examples_succeed(self):
        for v in get_valid_examples():
            self.assertTrue(is_valid_resource(v))
            validate_resource(v)

    def test_all_invalid_examples_fail(self):
        for i in get_invalid_examples():
            self.assertFalse(is_valid_resource(i))
            self.assertRaises(ValidationFailed, lambda: validate_resource(i))

class TestSchemas(unittest.TestCase):
    """ Schema unit test stubs """

    def test_there_are_schemas(self):
        for name in ["error", "search-response", "resource"]:
            self.assertTrue(name in get_schemas())

    def test_there_are_valid_examples(self):
        for schema in get_schemas().values():
            self.assertTrue(schema.get_valid_examples())

    def test_there_are_invalid_examples(self):
        for schema in get_schemas().values():
            self.assertTrue(schema.get_invalid_examples())

    def test_valid_and_invalid_examples_are_not_the_same(self):
        for schema in get_schemas().values():
            for v in schema.get_valid_examples():
                for i in schema.get_invalid_examples():
                    self.assertNotEqual(v, i, "A valid example can not be invalid.")

    def test_all_valid_examples_succeed(self):
        for schema in get_schemas().values():
            for v in schema.get_valid_examples():
                self.assertTrue(schema.is_valid(v))
                schema.validate(v)

    def test_all_invalid_examples_fail(self):
        for schema in get_schemas().values():
            for i in schema.get_invalid_examples():
                self.assertFalse(schema.is_valid(i))
                self.assertRaises(ValidationFailed, lambda: schema.validate(i))


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Schul-Cloud Content API

    This is the specification for the content of Schul-Cloud. You can find more information in the [repository](https://github.com/schul-cloud/resources-api-v1). 

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ResourceResponseData(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """
    def __init__(self, id=None, type=None, attributes=None):
        """
        ResourceResponseData - a model defined in Swagger

        :param dict swaggerTypes: The key is attribute name
                                  and the value is attribute type.
        :param dict attributeMap: The key is attribute name
                                  and the value is json key in definition.
        """
        self.swagger_types = {
            'id': 'str',
            'type': 'str',
            'attributes': 'Resource'
        }

        self.attribute_map = {
            'id': 'id',
            'type': 'type',
            'attributes': 'attributes'
        }

        self._id = id
        self._type = type
        self._attributes = attributes

    @property
    def id(self):
        """
        Gets the id of this ResourceResponseData.
        The id of the object.

        :return: The id of this ResourceResponseData.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ResourceResponseData.
        The id of the object.

        :param id: The id of this ResourceResponseData.
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")

        self._id = id

    @property
    def type(self):
        """
        Gets the type of this ResourceResponseData.
        The type of the object

        :return: The type of this ResourceResponseData.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """
        Sets the type of this ResourceResponseData.
        The type of the object

        :param type: The type of this ResourceResponseData.
        :type: str
        """
        allowed_values = ["resource"]
        if type not in allowed_values:
            raise ValueError(
                "Invalid value for `type` ({0}), must be one of {1}"
                .format(type, allowed_values)
            )

        self._type = type

    @property
    def attributes(self):
        """
        Gets the attributes of this ResourceResponseData.

        :return: The attributes of this ResourceResponseData.
        :rtype: Resource
        """
        return self._attributes

    @attributes.setter
    def attributes(self, attributes):
        """
        Sets the attributes of this ResourceResponseData.

        :param attributes: The attributes of this ResourceResponseData.
        :type: Resource
        """
        if attributes is None:
            raise ValueError("Invalid value for `attributes`, must not be `None`")

        self._attributes = attributes

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ResourceResponseData):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    Schul-Cloud Content API

    This is the specification for the content of Schul-Cloud. You can find more information in the [repository](https://github.com/schul-cloud/resources-api-v1). 

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import schul_cloud_resources_api_v1
from schul_cloud_resources_api_v1.rest import ApiException
from schul_cloud_resources_api_v1.models.resource_response_data import ResourceResponseData


class TestResourceResponseData(unittest.TestCase):
    """ ResourceResponseData unit test stubs """

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def testResourceResponseData(self):
        """
        Test ResourceResponseData
        """
        model = schul_cloud_resources_api_v1.models.resource_response_data.ResourceResponseData()


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Schul-Cloud Content API

    This is the specification for the content of Schul-Cloud. You can find more information in the [repository](https://github.com/schul-cloud/resources-api-v1). 

    OpenAPI spec version: 1.0.0
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from __future__ import absolute_import

import os
import sys
import unittest

import schul_cloud_resources_api_v1
from schul_cloud_resources_api_v1.rest import ApiException
from schul_cloud_resources_api_v1.apis.resource_api import ResourceApi


class TestResourceApi(unittest.TestCase):
    """ ResourceApi unit test stubs """

    def setUp(self):
        self.api = schul_cloud_resources_api_v1.apis.resource_api.ResourceApi()

    def tearDown(self):
        pass

    def test_add_resource(self):
        """
        Test case for add_resource

        Add new resources to the database
        """
        pass

    def test_delete_resource(self):
        """
        Test case for delete_resource

        Delete a resource
        """
        pass

    def test_delete_resources(self):
        """
        Test case for delete_resources

        Delete all resources
        """
        pass

    def test_get_resource(self):
        """
        Test case for get_resource

        Get a resource.
        """
        pass

    def test_get_resource_ids(self):
        """
        Test case for get_resource_ids

        Get the ids of all resources of the client
        """
        pass


if __name__ == '__main__':
    unittest.main()



import jsonschema
import os
import json
import sys


HERE = os.path.dirname(__file__)
JSON_PATH = os.path.join(HERE, "json")
NO_SCHEMA = ["test"]

ValidationFailed = jsonschema.exceptions.ValidationError


def _get_json_content_from_folder(folder):
    """yield objects from json files in the folder and subfolders."""
    for dirpath, dirnames, filenames in os.walk(folder):
        for filename in filenames:
            if filename.lower().endswith(".json"):
                filepath = os.path.join(dirpath, filename)
                with open(filepath, "rb") as file:
                    yield json.loads(file.read().decode("UTF-8"))


class Schema(object):
    """An interface to the schema on the file system."""

    def __init__(self, name):
        """Create a schema with a given name."""
        self._name = name

    def _get_schema_folder(self):
        """Return the path to the schema folder where all files are located."""
        return os.path.join(JSON_PATH, self._name)

    def get_schema(self):
        """Return the schema."""
        path = os.path.join(self._get_schema_folder(), self._name + ".json")
        with open(path, "rb") as file:
            schema = json.loads(file.read().decode("UTF-8"))
        return schema

    def get_uri(self):
        """Return the uri identifying this schema."""
        return self.get_schema()["id"]

    def get_resolver(self):
        """Return a jsonschema.RefResolver for the schemas.

        All schemas returned be get_schemas() are resolved locally.
        """
        store = {}
        for schema in get_schemas().values():
            store[schema.get_uri()] = schema.get_schema()
        schema = self.get_schema()
        return jsonschema.RefResolver.from_schema(schema, store=store)

    def validate(self, object):
        """Validate an object against the schema.

        This function just passes if the schema matches the object.
        If the object does not match the schema, a ValidationException is raised.
        This error allows debugging.
        """
        resolver=self.get_resolver()
        jsonschema.validate(object, self.get_schema(), resolver=resolver)

    def is_valid(self, object):
        """Return whether an object matches the schema."""
        try:
            self.validate(object)
        except ValidationFailed:
            return False
        return True

    def get_valid_examples(self):
        """Return a list of valid examples for the given schema."""
        path = os.path.join(self._get_schema_folder(), "examples", "valid")
        return list(_get_json_content_from_folder(path))

    def get_invalid_examples(self):
        """Return a list of examples which violate the schema."""
        path = os.path.join(self._get_schema_folder(), "examples", "invalid")
        return list(_get_json_content_from_folder(path))


def get_schemas():
    """Return a dict of schema names mapping to a Schema.

    The schema is of type schul_cloud_resources_api_v1.schema.Schema
    """
    schemas = {}
    for name in os.listdir(JSON_PATH):
        if name not in NO_SCHEMA:
            schemas[name] = Schema(name)
    return schemas


_resource_schema = get_schemas()["resource"]
get_resource_schema = _resource_schema.get_schema
validate_resource = _resource_schema.validate
is_valid_resource = _resource_schema.is_valid
get_valid_examples = _resource_schema.get_valid_examples
get_invalid_examples = _resource_schema.get_invalid_examples


__all__ = ["ValidationFailed", "validate_resource", "is_valid_resource",
           "get_valid_examples", "get_invalid_examples", "get_schemas",
           "Schema"]
